alfalfaSG: Field-book for a germination assay with alfalfa

alfalfaSGR Documentation

Field-book for a germination assay with alfalfa

Description

The germination of alfalfa was assayed at 7 temperature levels, on three replicated Petri dishes per temperature and 100 seeds per Petri dish. Inspections were made in several times after the beginning of the assay.

Usage

data("alfalfaSG")

Format

A data frame with 21 observations on the following variables.

Dish

a numeric vector with the coding for Petri dishes

Temp

a numeric vector with the temperature level

nViable

a numeric vector: number of viable seeds per dish

‘⁠1⁠’

a numeric vector: count at day 1

‘⁠2⁠’

a numeric vector: count at day 2

‘⁠3⁠’

a numeric vector: count at day 3

‘⁠4⁠’

a numeric vector: count at day 4

‘⁠5⁠’

a numeric vector: count at day 5

‘⁠6⁠’

a numeric vector: count at day 6

‘⁠7⁠’

a numeric vector: count at day 7

‘⁠8⁠’

a numeric vector: count at day 8

‘⁠9⁠’

a numeric vector: count at day 9

‘⁠10⁠’

a numeric vector: count at day 10

‘⁠11⁠’

a numeric vector: count at day 11

‘⁠12⁠’

a numeric vector: count at day 12

‘⁠13⁠’

a numeric vector: count at day 13

‘⁠14⁠’

a numeric vector: count at day 14

‘⁠15⁠’

a numeric vector: count at day 15

‘⁠16⁠’

a numeric vector: count at day 16

‘⁠17⁠’

a numeric vector: count at day 17

‘⁠18⁠’

a numeric vector: count at day 18

‘⁠19⁠’

a numeric vector: count at day 19

‘⁠20⁠’

a numeric vector: count at day 20

‘⁠21⁠’

a numeric vector: count at day 21

‘⁠22⁠’

a numeric vector: count at day 22

‘⁠23⁠’

a numeric vector: count at day 23

‘⁠24⁠’

a numeric vector: count at day 24

‘⁠27⁠’

a numeric vector: count at day 27

‘⁠28⁠’

a numeric vector: count at day 28

‘⁠29⁠’

a numeric vector: count at day 29

‘⁠31⁠’

a numeric vector: count at day 31

‘⁠34⁠’

a numeric vector: count at day 34

Details

Every line of data represents a Petri dish. There were 100 seeds per Petri dish. The columns represent the characteristics of each Petri dish. The columns from 4 to 32 represent the number of germinated seeds counted at each assessment time.

Author(s)

Andrea Onofri

no reference yet

References

Onofri, A., Benincasa, P., Mesgaran, M.B., Ritz, C., 2018. Hydrothermal-time-to-event models for seed germination. European Journal of Agronomy 101, 129–139.

Examples

data(alfalfaSG)
head(alfalfaSG)

OnofriAndreaPG/drcSeedGerm documentation built on Jan. 13, 2025, 5:53 a.m.